@@ -4,8 +4,16 @@ from pycobertura.cobertura import Cobertura
 from pycobertura.reporters import (
     HtmlReporter,
     TextReporter,
+    CsvReporter,
+    MarkdownReporter,
+    JsonReporter,
+    YamlReporter,
     HtmlReporterDelta,
     TextReporterDelta,
+    CsvReporterDelta,
+    MarkdownReporterDelta,
+    JsonReporterDelta,
+    YamlReporterDelta,
 )
 from pycobertura.filesystem import filesystem_factory
 from pycobertura.utils import get_dir_from_file_path
@@ -16,6 +24,10 @@ pycobertura = click.Group()
 reporters = {
     "html": HtmlReporter,
     "text": TextReporter,
+    "csv": CsvReporter,
+    "markdown": MarkdownReporter,
+    "json": JsonReporter,
+    "yaml": YamlReporter,
 }
 
 
@@ -46,7 +58,20 @@ def get_exit_code(differ, source):
 
 @pycobertura.command()
 @click.argument("cobertura_file")
+@click.option(
+    "--ignore-regex",
+    default=None,
+    type=str,
+    help="Regex for which files to ignore in output\n\t",
+)
 @click.option("-f", "--format", default="text", type=click.Choice(list(reporters)))
+@click.option(
+    "-delim",
+    "--delimiter",
+    default=";",
+    type=str,
+    help="Delimiter for csv format, e.g. ,;\n\t",
+)
 @click.option(
     "-o",
     "--output",
@@ -70,8 +95,11 @@ def get_exit_code(differ, source):
     "the --source is a zip archive and the files were zipped under "
     "a directory prefix that is not part of the source.",
 )
-def show(cobertura_file, format, output, source, source_prefix):
+def show(
+    cobertura_file, ignore_regex, format, delimiter, output, source, source_prefix
+):
     """show coverage summary of a Cobertura report"""
+
     if not source:
         source = get_dir_from_file_path(cobertura_file)
 
@@ -80,8 +108,12 @@ def show(cobertura_file, format, output, source, source_prefix):
         filesystem=filesystem_factory(source, source_prefix=source_prefix),
     )
     Reporter = reporters[format]
-    reporter = Reporter(cobertura)
-    report = reporter.generate()
+    reporter = Reporter(cobertura, ignore_regex)
+
+    if format == "csv":
+        report = reporter.generate(delimiter)
+    else:
+        report = reporter.generate()
 
     if not isinstance(report, bytes):
         report = report.encode("utf-8")
@@ -92,7 +124,11 @@ def show(cobertura_file, format, output, source, source_prefix):
 
 delta_reporters = {
     "text": TextReporterDelta,
+    "csv": CsvReporterDelta,
+    "markdown": MarkdownReporterDelta,
     "html": HtmlReporterDelta,
+    "json": JsonReporterDelta,
+    "yaml": YamlReporterDelta,
 }
 
 
@@ -112,6 +148,19 @@ directories (or zip archives). If the source is not available at all, pass
 )
 @click.argument("cobertura_file1")
 @click.argument("cobertura_file2")
+@click.option(
+    "--ignore-regex",
+    default=None,
+    type=str,
+    help="Regex for which files to ignore in output\n\t",
+)
+@click.option(
+    "-delim",
+    "--delimiter",
+    default=";",
+    type=str,
+    help="Delimiter for csv format, e.g. ,;\n\t",
+)
 @click.option(
     "--color/--no-color",
     default=None,
@@ -170,6 +219,8 @@ directories (or zip archives). If the source is not available at all, pass
 def diff(
     cobertura_file1,
     cobertura_file2,
+    ignore_regex,
+    delimiter,
     color,
     format,
     output,
@@ -195,17 +246,20 @@ def diff(
     cobertura2 = Cobertura(cobertura_file2, filesystem=filesystem2)
 
     Reporter = delta_reporters[format]
-    reporter_args = [cobertura1, cobertura2]
+    reporter_args = [cobertura1, cobertura2, ignore_regex]
     reporter_kwargs = {"show_source": source}
 
     isatty = True if output is None else output.isatty()
 
-    if format == "text":
+    if format in {"text", "csv", "json", "markdown", "yaml"}:
         color = isatty if color is None else color is True
         reporter_kwargs["color"] = color
 
     reporter = Reporter(*reporter_args, **reporter_kwargs)
-    report = reporter.generate()
+    if format == "csv":
+        report = reporter.generate(delimiter)
+    else:
+        report = reporter.generate()
 
     if not isinstance(report, bytes):
         report = report.encode("utf-8")
