@@ -6,6 +6,7 @@ from pycobertura.utils import (
     extrapolate_coverage,
     reconcile_lines,
     hunkify_lines,
+    get_filenames_that_do_not_match_regex,
     memoize,
 )
 
@@ -29,7 +30,7 @@ class Line(namedtuple("Line", ["number", "source", "status", "reason"])):
     """
 
 
-class Cobertura(object):
+class Cobertura:
     """
     An XML Cobertura parser.
     """
@@ -68,6 +69,16 @@ class Cobertura(object):
         self.filesystem = filesystem
         self.report = report
 
+        self._class_elements_by_file_name = self._make_class_elements_by_filename()
+
+    def _make_class_elements_by_filename(self):
+        result = {}
+        for elem in self.xml.xpath("./packages//class"):
+            filename = elem.attrib["filename"]
+            result.setdefault(filename, []).append(elem)
+
+        return result
+
     def __eq__(self, other):
         return self.report and other.report and self.report == other.report
 
@@ -77,32 +88,35 @@ class Cobertura(object):
     def _load_from_string(self, s):
         return ET.fromstring(s)
 
-    @memoize
-    def _get_class_element_by_filename(self, filename):
-        syntax = "./packages//class[@filename='%s'][1]" % (filename)
-        return self.xml.xpath(syntax)[0]
-
     @memoize
     def _get_lines_by_filename(self, filename):
-        el = self._get_class_element_by_filename(filename)
-        return el.xpath("./lines/line")
+        classElements = self._class_elements_by_file_name[filename]
+        return [
+            line
+            for classElement in classElements
+            for line in classElement.xpath("./lines/line")
+        ]
 
     @property
     def version(self):
         """Return the version number of the coverage report."""
-        return self.xml.attrib["version"]
+        return self.xml.get("version")
 
     def line_rate(self, filename=None):
         """
         Return the global line rate of the coverage report. If the
         `filename` file is given, return the line rate of the file.
         """
-        if filename is None:
-            el = self.xml
-        else:
-            el = self._get_class_element_by_filename(filename)
 
-        return float(el.attrib["line-rate"])
+        if filename is None:
+            return float(self.xml.get("line-rate"))
+
+        elements = self._class_elements_by_file_name[filename]
+        if len(elements) == 1:
+            return float(elements[0].get("line-rate"))
+        else:
+            total = self.total_statements(filename)
+            return float(self.total_hits(filename) / total) if total != 0 else 0
 
     def branch_rate(self, filename=None):
         """
@@ -110,11 +124,10 @@ class Cobertura(object):
         `filename` file is given, return the branch rate of the file.
         """
         if filename is None:
-            el = self.xml
+            return float(self.xml.get("branch-rate"))
         else:
-            el = self._get_class_element_by_filename(filename)
-
-        return float(el.attrib["branch-rate"])
+            classElement = self._class_elements_by_file_name[filename][0]
+            return float(classElement.get("branch-rate"))
 
     @memoize
     def missed_statements(self, filename):
@@ -122,9 +135,12 @@ class Cobertura(object):
         Return a list of uncovered line numbers for each of the missed
         statements found for the file `filename`.
         """
-        el = self._get_class_element_by_filename(filename)
-        lines = el.xpath("./lines/line[@hits=0]")
-        return [int(line.attrib["number"]) for line in lines]
+        classElements = self._class_elements_by_file_name[filename]
+        return [
+            int(line.get("number"))
+            for classElement in classElements
+            for line in classElement.xpath("./lines/line[@hits=0]")
+        ]
 
     @memoize
     def hit_statements(self, filename):
@@ -132,9 +148,12 @@ class Cobertura(object):
         Return a list of covered line numbers for each of the hit statements
         found for the file `filename`.
         """
-        el = self._get_class_element_by_filename(filename)
-        lines = el.xpath("./lines/line[@hits>0]")
-        return [int(line.attrib["number"]) for line in lines]
+        classElements = self._class_elements_by_file_name[filename]
+        return [
+            int(line.get("number"))
+            for classElement in classElements
+            for line in classElement.xpath("./lines/line[@hits>0]")
+        ]
 
     def line_statuses(self, filename):
         """
@@ -144,14 +163,9 @@ class Cobertura(object):
         be either `True` (line hit) or `False` (line miss).
         """
         line_elements = self._get_lines_by_filename(filename)
-
-        lines_w_status = []
-        for line in line_elements:
-            lineno = int(line.attrib["number"])
-            status = line.attrib["hits"] != "0"
-            lines_w_status.append((lineno, status))
-
-        return lines_w_status
+        return [
+            (int(line.get("number")), line.get("hits") != "0") for line in line_elements
+        ]
 
     def missed_lines(self, filename):
         """
@@ -164,10 +178,10 @@ class Cobertura(object):
 
     def _raise_MissingFileSystem(self, filename):
         raise self.MissingFileSystem(
-            "Unable to read file: {filename}. "
-            "A FileSystem instance must be provided via "
-            "Cobertura(filesystem=...) to locate and read the source "
-            "content of the file.".format(filename=filename)
+            f"Unable to read file: {filename}. "
+            f"A FileSystem instance must be provided via "
+            f"Cobertura(filesystem=...) to locate and read the source "
+            f"content of the file."
         )
 
     @memoize
@@ -189,7 +203,7 @@ class Cobertura(object):
                     lines.append(line)
 
         except self.filesystem.FileNotFound as file_not_found:
-            lines.append(Line(0, "%s not found" % file_not_found.path, None, None))
+            lines.append(Line(0, f"{file_not_found.path} not found", None, None))
 
         return lines
 
@@ -202,11 +216,7 @@ class Cobertura(object):
         if filename is not None:
             return len(self.missed_statements(filename))
 
-        total = 0
-        for filename in self.files():
-            total += len(self.missed_statements(filename))
-
-        return total
+        return sum([len(self.missed_statements(filename)) for filename in self.files()])
 
     def total_hits(self, filename=None):
         """
@@ -217,11 +227,7 @@ class Cobertura(object):
         if filename is not None:
             return len(self.hit_statements(filename))
 
-        total = 0
-        for filename in self.files():
-            total += len(self.hit_statements(filename))
-
-        return total
+        return sum([len(self.hit_statements(filename)) for filename in self.files()])
 
     def total_statements(self, filename=None):
         """
@@ -230,18 +236,14 @@ class Cobertura(object):
         number of statements for all files.
         """
         if filename is not None:
-            statements = self._get_lines_by_filename(filename)
-            return len(statements)
+            return len(self._get_lines_by_filename(filename))
 
-        total = 0
-        for filename in self.files():
-            statements = self._get_lines_by_filename(filename)
-            total += len(statements)
-
-        return total
+        return sum(
+            [len(self._get_lines_by_filename(filename)) for filename in self.files()]
+        )
 
     @memoize
-    def files(self):
+    def files(self, ignore_regex=None):
         """
         Return the list of available files in the coverage report.
         """
@@ -250,13 +252,17 @@ class Cobertura(object):
         filenames = []
 
         for el in self.xml.xpath("//class"):
-            filename = el.attrib["filename"]
+            filename = el.get("filename")
             if filename in already_seen:
                 continue
             already_seen.add(filename)
             filenames.append(filename)
 
-        return filenames
+        return (
+            filenames
+            if not ignore_regex
+            else get_filenames_that_do_not_match_regex(filenames, ignore_regex)
+        )
 
     def has_file(self, filename):
         """
@@ -282,10 +288,10 @@ class Cobertura(object):
         """
         Return the list of available packages in the coverage report.
         """
-        return [el.attrib["name"] for el in self.xml.xpath("//package")]
+        return [el.get("name") for el in self.xml.xpath("//package")]
 
 
-class CoberturaDiff(object):
+class CoberturaDiff:
     """
     Diff Cobertura objects.
     """
@@ -301,10 +307,9 @@ class CoberturaDiff(object):
         This does not ensure that all changes have been covered. If this is
         what you want, use `CoberturaDiff.has_all_changes_covered()` instead.
         """
-        for filename in self.files():
-            if self.diff_total_misses(filename) > 0:
-                return False
-        return True
+        return not (
+            any(self.diff_total_misses(filename) > 0 for filename in self.files())
+        )
 
     def has_all_changes_covered(self):
         """
@@ -331,10 +336,7 @@ class CoberturaDiff(object):
 
         The returned count may be a float.
         """
-        if filename is not None:
-            files = [filename]
-        else:
-            files = self.files()
+        files = [filename] if filename else self.files()
 
         total_count = 0.0
         for filename in files:
@@ -365,23 +367,18 @@ class CoberturaDiff(object):
 
     def diff_missed_lines(self, filename):
         """
-        Return a list of 2-element tuples `(lineno, is_new)` for the given
-        file `filename` where `lineno` is a missed line number and `is_new`
-        indicates whether the missed line was introduced (True) or removed
-        (False).
+        Return a list of 2-element tuples `(lineno, True)` for uncovered lines.
+        The given file `filename` where `lineno` is a missed line number.
         """
-        line_changed = []
-        for line in self.file_source(filename):
-            if line.status is not None:
-                is_new = not line.status
-                line_changed.append((line.number, is_new))
-        return line_changed
+        return [
+            line.number for line in self.file_source(filename) if line.status is False
+        ]
 
-    def files(self):
+    def files(self, ignore_regex=None):
         """
         Return `self.cobertura2.files()`.
         """
-        return self.cobertura2.files()
+        return self.cobertura2.files(ignore_regex)
 
     def file_source(self, filename):
         """
