@@ -17,6 +17,16 @@ line_reason_html_icon = {
 }
 
 
+def is_not_equal_to_dash(arg):
+    return not (arg == "-")
+
+
+def misses_color(arg):
+    if arg.startswith("+") or arg[0].isdigit():
+        return "red"
+    return "green"
+
+
 def line_status(line):
     return line_status_style[line.status]
 
