@@ -1,5 +1,7 @@
 import difflib
 import os
+import re
+import fnmatch
 
 from functools import partial
 
@@ -12,7 +14,7 @@ ANSI_ESCAPE_CODES = {
 
 # Recipe from https://github.com/ActiveState/
 # code/recipes/Python/577452_memoize_decorator_instance/recipe-577452.py
-class memoize(object):
+class memoize:
     """cache the return value of a method
 
     This class is meant to be used as a decorator of methods. The return value
@@ -22,7 +24,7 @@ class memoize(object):
 
     If a memoized method is invoked directly on its class the result will not
     be cached. Instead the method will be invoked like a static method:
-    class Obj(object):
+    class Obj:
         @memoize
         def add_to(self, arg):
             return self + arg
@@ -54,7 +56,7 @@ class memoize(object):
 
 def colorize(text, color):
     color_code = ANSI_ESCAPE_CODES[color]
-    return "%s%s%s" % (color_code, text, ANSI_ESCAPE_CODES["reset"])
+    return f'{color_code}{text}{ANSI_ESCAPE_CODES["reset"]}'
 
 
 def red(text):
@@ -83,6 +85,16 @@ def rangify(number_list):
     return ranges
 
 
+def stringify(number_list):
+    """Assumes the list is sorted."""
+    rangified_list = rangify(number_list)
+    stringified_list = [
+        f"{line_start}" if line_start == line_stop else f"{line_start}-{line_stop}"
+        for line_start, line_stop in rangified_list
+    ]
+    return ", ".join(stringified_list)
+
+
 def extrapolate_coverage(lines_w_status):
     """
     Given the following input:
@@ -219,3 +231,30 @@ def hunkify_lines(lines, context=3):
 
 def get_dir_from_file_path(file_path):
     return os.path.dirname(file_path) or "."
+
+
+def get_non_empty_non_commented_lines_from_file_in_ascii(file_path, comment_character):
+    with open(file_path, "rb") as f:  # read in binary (more secure)
+        result = [
+            line.decode("ascii").strip()
+            for line in f.readlines()
+            if not line.decode("ascii").startswith(comment_character)
+        ]
+        return [res for res in result if res != ""]
+
+
+def get_filenames_that_do_not_match_regex(
+    filenames, regex_param, comment_character="#"
+):
+    if os.path.isfile(regex_param):
+        ignore_patterns = get_non_empty_non_commented_lines_from_file_in_ascii(
+            regex_param, comment_character
+        )
+        remove_filenames = [
+            filename
+            for igp in ignore_patterns
+            for filename in fnmatch.filter(filenames, igp)
+        ]
+    else:
+        remove_filenames = list(filter(re.compile(regex_param).match, filenames))
+    return [fname for fname in filenames if fname not in remove_filenames]
