@@ -19,11 +19,11 @@ def test_text_report():
     assert report.generate() == """\
 Filename                          Stmts    Miss  Cover    Missing
 ------------------------------  -------  ------  -------  ---------
-Main.java                            11       0  100.00%
+Main.java                            15       0  100.00%
 search/BinarySearch.java             12       1  91.67%   24
 search/ISortedArraySearch.java        0       0  100.00%
 search/LinearSearch.java              7       2  71.43%   19-24
-TOTAL                                30       3  90.00%"""
+TOTAL                                34       3  90.00%"""
 
 
 def test_text_report__with_missing_range():
@@ -50,9 +50,9 @@ def test_text_report_delta__no_diff():
     report_delta = TextReporterDelta(cobertura1, cobertura2)
 
     assert report_delta.generate() == """\
-Filename    Stmts    Miss    Cover    Missing
-----------  -------  ------  -------  ---------
-TOTAL       -        -       -"""
+Filename      Stmts    Miss  Cover     Missing
+----------  -------  ------  --------  ---------
+TOTAL             0       0  +100.00%"""
 
 
 def test_text_report_delta__colorize_True():
@@ -64,12 +64,12 @@ def test_text_report_delta__colorize_True():
     report_delta = TextReporterDelta(cobertura1, cobertura2, color=True)
 
     assert report_delta.generate() == """\
-Filename         Stmts      Miss  Cover    Missing
----------------  -------  ------  -------  ----------
-dummy/dummy.py   -            \x1b[32m-2\x1b[39m  +40.00%  \x1b[32m-5\x1b[39m, \x1b[32m-6\x1b[39m
-dummy/dummy2.py  +2           \x1b[31m+1\x1b[39m  -25.00%  \x1b[32m-2\x1b[39m, \x1b[32m-4\x1b[39m, \x1b[31m+5\x1b[39m
-dummy/dummy3.py  +2           \x1b[31m+2\x1b[39m  -        \x1b[31m+1\x1b[39m, \x1b[31m+2\x1b[39m
-TOTAL            +4           \x1b[31m+1\x1b[39m  +31.06%"""
+Filename           Stmts    Miss  Cover     Missing
+---------------  -------  ------  --------  ---------
+dummy/dummy.py         0      \x1b[32m-2\x1b[39m  +40.00%
+dummy/dummy2.py       +2      \x1b[31m+1\x1b[39m  -25.00%   \x1b[31m5\x1b[39m
+dummy/dummy3.py       +2      \x1b[31m+2\x1b[39m  +100.00%  \x1b[31m1\x1b[39m, \x1b[31m2\x1b[39m
+TOTAL                 +4      \x1b[31m+1\x1b[39m  +31.06%"""
 
 
 def test_text_report_delta__colorize_True__with_missing_range():
@@ -81,12 +81,12 @@ def test_text_report_delta__colorize_True__with_missing_range():
     report_delta = TextReporterDelta(cobertura1, cobertura2, color=True)
 
     assert report_delta.generate() == """\
-Filename         Stmts      Miss  Cover    Missing
----------------  -------  ------  -------  ----------
-dummy/dummy.py   -            \x1b[32m-2\x1b[39m  +40.00%  \x1b[32m-5\x1b[39m, \x1b[32m-6\x1b[39m
-dummy/dummy2.py  +2           \x1b[31m+1\x1b[39m  -25.00%  \x1b[32m-2\x1b[39m, \x1b[32m-4\x1b[39m, \x1b[31m+5\x1b[39m
-dummy/dummy3.py  +2           \x1b[31m+2\x1b[39m  -        \x1b[31m+1\x1b[39m, \x1b[31m+2\x1b[39m
-TOTAL            +4           \x1b[31m+1\x1b[39m  +31.06%"""
+Filename           Stmts    Miss  Cover     Missing
+---------------  -------  ------  --------  ---------
+dummy/dummy.py         0      \x1b[32m-2\x1b[39m  +40.00%
+dummy/dummy2.py       +2      \x1b[31m+1\x1b[39m  -25.00%   \x1b[31m5\x1b[39m
+dummy/dummy3.py       +2      \x1b[31m+2\x1b[39m  +100.00%  \x1b[31m1\x1b[39m, \x1b[31m2\x1b[39m
+TOTAL                 +4      \x1b[31m+1\x1b[39m  +31.06%"""
 
 
 def test_text_report_delta__colorize_False():
@@ -98,12 +98,12 @@ def test_text_report_delta__colorize_False():
     report_delta = TextReporterDelta(cobertura1, cobertura2, color=False)
 
     assert report_delta.generate() == """\
-Filename         Stmts      Miss  Cover    Missing
----------------  -------  ------  -------  ----------
-dummy/dummy.py   -            -2  +40.00%  -5, -6
-dummy/dummy2.py  +2           +1  -25.00%  -2, -4, +5
-dummy/dummy3.py  +2           +2  -        +1, +2
-TOTAL            +4           +1  +31.06%"""
+Filename           Stmts    Miss  Cover     Missing
+---------------  -------  ------  --------  ---------
+dummy/dummy.py         0      -2  +40.00%
+dummy/dummy2.py       +2      +1  -25.00%   5
+dummy/dummy3.py       +2      +2  +100.00%  1, 2
+TOTAL                 +4      +1  +31.06%"""
 
 
 def test_html_report():
@@ -138,7 +138,7 @@ def test_html_report():
         <tbody>
           <tr>
             <td><a href="#Main.java">Main.java</a></td>
-            <td>11</td>
+            <td>15</td>
             <td>0</td>
             <td>100.00%</td>
             <td></td>
@@ -168,7 +168,7 @@ def test_html_report():
         <tfoot>
           <tr>
             <td>TOTAL</td>
-            <td>30</td>
+            <td>34</td>
             <td>3</td>
             <td>90.00%</td>
             <td></td>
@@ -269,7 +269,7 @@ def test_html_report__no_source_files_message():
         <tbody>
           <tr>
             <td>Main.java</td>
-            <td>11</td>
+            <td>15</td>
             <td>0</td>
             <td>100.00%</td>
             <td></td>
@@ -299,7 +299,7 @@ def test_html_report__no_source_files_message():
         <tfoot>
           <tr>
             <td>TOTAL</td>
-            <td>30</td>
+            <td>34</td>
             <td>3</td>
             <td>90.00%</td>
             <td></td>
@@ -321,12 +321,12 @@ def test_text_report_delta__no_source():
     report_delta = TextReporterDelta(cobertura1, cobertura2, show_source=False)
     output = report_delta.generate()
     assert output == """\
-Filename         Stmts      Miss  Cover
----------------  -------  ------  -------
-dummy/dummy.py   -            -2  +40.00%
-dummy/dummy2.py  +2           +1  -25.00%
-dummy/dummy3.py  +2           +2  -
-TOTAL            +4           +1  +31.06%"""
+Filename           Stmts    Miss  Cover
+---------------  -------  ------  --------
+dummy/dummy.py         0      -2  +40.00%
+dummy/dummy2.py       +2      +1  -25.00%
+dummy/dummy3.py       +2      +2  +100.00%
+TOTAL                 +4      +1  +31.06%"""
 
 
 def test_html_report_delta__no_source():
@@ -360,7 +360,7 @@ def test_html_report_delta__no_source():
         <tbody>
           <tr>
             <td><a href="#dummy/dummy.py">dummy/dummy.py</a></td>
-            <td>-</td>
+            <td>0</td>
             <td><span class="green">-2</span></td>
             <td>+40.00%</td>
           </tr>
@@ -374,7 +374,7 @@ def test_html_report_delta__no_source():
             <td><a href="#dummy/dummy3.py">dummy/dummy3.py</a></td>
             <td>+2</td>
             <td><span class="red">+2</span></td>
-            <td>-</td>
+            <td>+100.00%</td>
           </tr>
         </tbody>
         <tfoot>
@@ -425,10 +425,10 @@ def test_html_report_delta():
         <tbody>
           <tr>
             <td><a href="#dummy/dummy.py">dummy/dummy.py</a></td>
-            <td>-</td>
+            <td>0</td>
             <td><span class="green">-2</span></td>
             <td>+40.00%</td>
-            <td><span class="green">-5</span>, <span class="green">-6</span>
+            <td>
             </td>
           </tr>
           <tr>
@@ -436,15 +436,15 @@ def test_html_report_delta():
             <td>+2</td>
             <td><span class="red">+1</span></td>
             <td>-25.00%</td>
-            <td><span class="green">-2</span>, <span class="green">-4</span>, <span class="red">+5</span>
+            <td><span class="red">5</span>
             </td>
           </tr>
           <tr>
             <td><a href="#dummy/dummy3.py">dummy/dummy3.py</a></td>
             <td>+2</td>
             <td><span class="red">+2</span></td>
-            <td>-</td>
-            <td><span class="red">+1</span>, <span class="red">+2</span>
+            <td>+100.00%</td>
+            <td><span class="red">1</span>, <span class="red">2</span>
             </td>
           </tr>
         </tbody>
@@ -562,7 +562,7 @@ def test_html_report_delta__show_missing_False():
         <tbody>
           <tr>
             <td><a href="#dummy/dummy.py">dummy/dummy.py</a></td>
-            <td>-</td>
+            <td>0</td>
             <td><span class="green">-2</span></td>
             <td>+40.00%</td>
           </tr>
@@ -576,7 +576,7 @@ def test_html_report_delta__show_missing_False():
             <td><a href="#dummy/dummy3.py">dummy/dummy3.py</a></td>
             <td>+2</td>
             <td><span class="red">+2</span></td>
-            <td>-</td>
+            <td>+100.00%</td>
           </tr>
         </tbody>
         <tfoot>
